@@ -21,8 +21,6 @@
 #define AKONADICONSOLE_NOTIFICATIONMODEL_H
 
 #include <QAbstractItemModel>
-#include <QDateTime>
-#include <QDBusInterface>
 
 #include <AkonadiCore/Monitor>
 #include <AkonadiCore/ChangeNotification>
@@ -75,7 +73,7 @@ private:
 
     QList<Item *> m_data;
 
-    Akonadi::Monitor *m_monitor;
+    Akonadi::Monitor *m_monitor = nullptr;
 };
 
 #endif
